@@ -1,33 +1,30 @@
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 use std::sync::mpsc::SyncSender;
 use enigo::Key;
 use streamduck_core::core::button::{Button, Component, parse_button_to_component, parse_unique_button_to_component};
 use streamduck_core::core::UniqueButton;
 use streamduck_core::modules::components::{ComponentDefinition, map_ui_values, map_ui_values_ref, UIField, UIFieldType, UIFieldValue, UIValue};
-use streamduck_core::threads::rendering::{ButtonBackground, ButtonText, RendererComponent};
-use streamduck_core::util::rendering::TextAlignment;
+use streamduck_core::thread::rendering::{ButtonBackground, ButtonText, RendererComponentBuilder};
+use streamduck_core::thread::util::TextAlignment;
 
 pub fn add_definition(map: &mut HashMap<String, ComponentDefinition>) {
     map.insert("key_sequence".to_string(), ComponentDefinition {
         display_name: "Key Sequence".to_string(),
         description: "Performs a sequence of keystrokes defined by component's parameters".to_string(),
-        default_looks: RendererComponent {
-            background: ButtonBackground::Solid((50, 50, 50, 255)),
-            text: vec![
-                ButtonText {
-                    text: "Aa".to_string(),
-                    font: "default".to_string(),
-                    scale: (30.0, 30.0),
-                    alignment: TextAlignment::Center,
-                    padding: 0,
-                    offset: (0.0, 0.0),
-                    color: (255, 255, 255, 255),
-                    shadow: None
-                }
-            ],
-            to_cache: true
-        }
+        default_looks: RendererComponentBuilder::new()
+            .background(ButtonBackground::Solid((50, 50, 50, 255)))
+            .add_text(ButtonText {
+                text: "Aa".to_string(),
+                font: "default".to_string(),
+                scale: (30.0, 30.0),
+                alignment: TextAlignment::Center,
+                padding: 0,
+                offset: (0.0, 0.0),
+                color: (255, 255, 255, 255),
+                shadow: None
+            })
+            .build()
     });
 }
 
@@ -160,17 +157,20 @@ pub fn get_values(button: &Button) -> Vec<UIValue> {
             UIValue {
                 name: "actions".to_string(),
                 display_name: "Key Actions".to_string(),
+                description: "Sequence of actions to perform on button press".to_string(),
                 ty: UIFieldType::Array(
                     vec![
                         UIField {
                             name: "type".to_string(),
                             display_name: "Action Type".to_string(),
+                            description: "Type of action to perform".to_string(),
                             ty: UIFieldType::Choice(action_types.clone()),
                             default_value: UIFieldValue::Choice("Click".to_string())
                         },
                         UIField {
                             name: "key".to_string(),
                             display_name: "Key".to_string(),
+                            description: "Key to use".to_string(),
                             ty: UIFieldType::Choice(key_variants()),
                             default_value: UIFieldValue::Choice("Alt".to_string())
                         }
@@ -186,6 +186,7 @@ pub fn get_values(button: &Button) -> Vec<UIValue> {
                             UIValue {
                                 name: "type".to_string(),
                                 display_name: "Action Type".to_string(),
+                                description: "Type of action to perform".to_string(),
                                 ty: UIFieldType::Choice(action_types.clone()),
                                 value: UIFieldValue::Choice(
                                     match &key_action {
@@ -208,6 +209,7 @@ pub fn get_values(button: &Button) -> Vec<UIValue> {
                                     UIValue {
                                         name: "key".to_string(),
                                         display_name: "Key".to_string(),
+                                        description: "Key to use".to_string(),
                                         ty: UIFieldType::Choice(key_variants()),
                                         value: UIFieldValue::Choice(choice)
                                     }
@@ -218,6 +220,7 @@ pub fn get_values(button: &Button) -> Vec<UIValue> {
                                         UIValue {
                                             name: "char".to_string(),
                                             display_name: "Character".to_string(),
+                                            description: "Character to use".to_string(),
                                             ty: UIFieldType::InputFieldString,
                                             value: UIFieldValue::InputFieldString(char.to_string())
                                         }
@@ -230,6 +233,7 @@ pub fn get_values(button: &Button) -> Vec<UIValue> {
                                     UIValue {
                                         name: "delay".to_string(),
                                         display_name: "Delay".to_string(),
+                                        description: "Amount of time to wait".to_string(),
                                         ty: UIFieldType::InputFieldFloat,
                                         value: UIFieldValue::InputFieldFloat(delay)
                                     }
@@ -241,6 +245,7 @@ pub fn get_values(button: &Button) -> Vec<UIValue> {
                                     UIValue {
                                         name: "text".to_string(),
                                         display_name: "Text".to_string(),
+                                        description: "Text to write, non-ascii text might lag the libxdo".to_string(),
                                         ty: UIFieldType::InputFieldString,
                                         value: UIFieldValue::InputFieldString(text)
                                     }
