@@ -1,33 +1,30 @@
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 use std::process::Command;
 use std::thread::spawn;
 use streamduck_core::core::button::{Button, Component, parse_button_to_component, parse_unique_button_to_component};
 use streamduck_core::core::UniqueButton;
 use streamduck_core::modules::components::{ComponentDefinition, map_ui_values, map_ui_values_ref, UIField, UIFieldType, UIFieldValue, UIValue};
-use streamduck_core::threads::rendering::{ButtonBackground, ButtonText, RendererComponent};
-use streamduck_core::util::rendering::TextAlignment;
+use streamduck_core::thread::rendering::{ButtonBackground, ButtonText, RendererComponentBuilder};
+use streamduck_core::thread::util::TextAlignment;
 
 pub fn add_definition(map: &mut HashMap<String, ComponentDefinition>) {
     map.insert("run_command".to_string(), ComponentDefinition {
         display_name: "Run Command".to_string(),
         description: "Runs a provided command".to_string(),
-        default_looks: RendererComponent {
-            background: ButtonBackground::Solid((50, 50, 50, 255)),
-            text: vec![
-                ButtonText {
-                    text: ">_".to_string(),
-                    font: "default".to_string(),
-                    scale: (30.0, 30.0),
-                    alignment: TextAlignment::Center,
-                    padding: 0,
-                    offset: (0.0, 0.0),
-                    color: (255, 255, 255, 255),
-                    shadow: None
-                }
-            ],
-            to_cache: true
-        }
+        default_looks: RendererComponentBuilder::new()
+            .background(ButtonBackground::Solid((50, 50, 50, 255)))
+            .add_text(ButtonText {
+                text: ">_".to_string(),
+                font: "default".to_string(),
+                scale: (30.0, 30.0),
+                alignment: TextAlignment::Center,
+                padding: 0,
+                offset: (0.0, 0.0),
+                color: (255, 255, 255, 255),
+                shadow: None
+            })
+            .build()
     });
 }
 
@@ -39,6 +36,7 @@ pub fn get_values(button: &Button) -> Vec<UIValue> {
             UIValue {
                 name: "use_advanced".to_string(),
                 display_name: "Advanced mode".to_string(),
+                description: "Advanced mode allows for more granular control over arguments".to_string(),
                 ty: UIFieldType::Checkbox {
                     disabled: false
                 },
@@ -51,10 +49,12 @@ pub fn get_values(button: &Button) -> Vec<UIValue> {
                 UIValue {
                     name: "args".to_string(),
                     display_name: "Arguments".to_string(),
+                    description: "Arguments to put into shell".to_string(),
                     ty: UIFieldType::Array(vec![
                         UIField {
                             name: "arg".to_string(),
                             display_name: "Argument".to_string(),
+                            description: "".to_string(),
                             ty: UIFieldType::InputFieldString,
                             default_value: UIFieldValue::InputFieldString("".to_string())
                         }
@@ -69,6 +69,7 @@ pub fn get_values(button: &Button) -> Vec<UIValue> {
                                 UIValue {
                                     name: "arg".to_string(),
                                     display_name: "Argument".to_string(),
+                                    description: "".to_string(),
                                     ty: UIFieldType::InputFieldString,
                                     value: UIFieldValue::InputFieldString(arg.to_string())
                                 }
@@ -86,6 +87,7 @@ pub fn get_values(button: &Button) -> Vec<UIValue> {
                 UIValue {
                     name: "command".to_string(),
                     display_name: "Command".to_string(),
+                    description: "Command to execute in the shell, splits arguments by spaces, if you need file names with spaces, use advanced mode instead".to_string(),
                     ty: UIFieldType::InputFieldString,
                     value: UIFieldValue::InputFieldString(component.simple_command)
                 }
@@ -177,7 +179,7 @@ pub fn action(button: &UniqueButton) {
 }
 
 
-#[derive(Serialize, Deserialize, Default, Debug)]
+#[derive(Serialize, Deserialize, Hash, Default, Debug)]
 pub struct RunCommandComponent {
     pub simple_command: String,
     pub advanced_command: Vec<String>,
